pub struct ContainerRef {
id: ContainerId,
source: SharedContainer,
owner: Option<Arc<BlockEntityBase>>,
}Expand description
A reference to a container that can be locked.
The optional owner is notified only after all container locks have been
released at the corresponding Vanilla setChanged boundary.
Fields
id: ContainerIdsource: SharedContainerowner: Option<Arc<BlockEntityBase>>Implementations
Sourceimpl ContainerRef
impl ContainerRef
Sourcepub fn from_block_entity(block_entity: SharedBlockEntity) -> Option<Self>
pub fn from_block_entity(block_entity: SharedBlockEntity) -> Option<Self>
Creates a ContainerRef from a block entity, if it implements Container.
Returns None if the block entity has no container capability.
Sourcepub fn owned_by_block_entity(
container: SharedContainer,
owner: Arc<BlockEntityBase>,
) -> Self
pub fn owned_by_block_entity( container: SharedContainer, owner: Arc<BlockEntityBase>, ) -> Self
Creates a container capability owned by the block entity whose unique
base is returned from its crate::block_entity::BlockEntity::base.
The container implementation must obey Container’s storage-local
locking contract. This owner performs block-entity and comparator
notifications after all container locks are released.
Sourcepub const fn container_id(&self) -> ContainerId
pub const fn container_id(&self) -> ContainerId
Returns a unique identifier for this container based on its Arc pointer address.
Sourcepub fn still_valid(&self, player: &Player) -> bool
pub fn still_valid(&self, player: &Player) -> bool
Checks container access without locking its item storage.
Sourcefn lock(&self) -> LockedContainer
fn lock(&self) -> LockedContainer
Locks this container and returns a guard.